==> librenms-22.2.0v0.tgz: librenms/doc/index.md <==
<div class="home-container">
    <div class="home-box">
        <div class="home-header">
          <a href="/Installation/">
            <i class="fas fa-download"></i>
            <span>Installing</span>
          </a>
        </div>
        <a href="/Installation/Install-LibreNMS/">Install LibreNMS Now</a><br />
        <a href="/Installation/Docker/">Install Using Docker</a><br />
        <a href="/Installation/Images/">Virtual machines</a>
    </div>
    <div class="home-box">
        <div class="home-header">
            <i class="fas fa-plug"></i>
            <span>Setup</span>
        </div>
        <a href="/Extensions/Applications/">Applications</a><br />
        <a href="/Extensions/Auto-Discovery/">Auto Discovery</a><br />
        <a href="/Extensions/Oxidized/">Oxidized</a><br />
        <a href="/Extensions/RRDCached/">RRDCached</a><br />
    </div>
    <div class="home-box">
        <div class="home-header">
          <a href="/Alerting/">
            <i class="fas fa-bell"></i>
            <span>Alerting</span>
          </a>
        </div>
        <a href="/Alerting/Rules/#rules">Rules</a><br />
        <a href="/Alerting/Templates/">Templates</a><br />
        <a href="/Alerting/Transports/">Transports</a><br />
        <a href="/Alerting/"><strong>More...</strong></a>
    </div>
    <div class="home-box">
        <div class="home-header">
          <a href="/API/">
            <i class="fas fa-connectdevelop"></i>
            <span>API</span>
          </a>
        </div>
        <a href="/API/">Using the API</a><br />
        <a href="/API/#endpoint-categories">API Endpoints</a><br />
        <br />
        <br />
    </div>
    <div class="home-box">
        <div class="home-header">
          <a href="/Support/">
            <i class="fas fa-ambulance"></i>
            <span>Support</span>
          </a>
        </div>
        <a href="/Support/FAQ/">FAQ</a><br />
        <a href="/Support/Install%20Validation/">Install validation</a><br />
        <a href="/Support/Performance/">Performance tweaks</a><br />
        <a href="/Support/"><strong>More...</strong></a>
    </div>
    <div class="home-box">
        <div class="home-header">
          <a href="/Developing/">
            <i class="fas fa-code-branch"></i>
            <span>Developing</span>
          </a>
        </div>
        <a href="/Developing/Getting-Started/">Getting Started</a><br />
        <a href="/Developing/Support-New-OS/">Support for a new OS</a><br />
    </div>
</div>

==> librenms-23.2.0v0.tgz: librenms/doc/index.md <==
<div class="home-container">
    <div class="home-box">
        <div class="home-header">
          <a href="/Installation/">
            <i class="fas fa-download"></i>
            <span>Installing</span>
          </a>
        </div>
        <a href="/Installation/Install-LibreNMS/">Install LibreNMS Now</a><br />
        <a href="/Installation/Docker/">Install Using Docker</a><br />
        <a href="/Installation/Images/">Virtual machines</a>
    </div>
    <div class="home-box">
        <div class="home-header">
            <i class="fas fa-plug"></i>
            <span>Setup</span>
        </div>
        <a href="/Extensions/Applications/">Applications</a><br />
        <a href="/Extensions/Auto-Discovery/">Auto Discovery</a><br />
        <a href="/Extensions/Oxidized/">Oxidized</a><br />
        <a href="/Extensions/RRDCached/">RRDCached</a><br />
    </div>
    <div class="home-box">
        <div class="home-header">
          <a href="/Alerting/">
            <i class="fas fa-bell"></i>
            <span>Alerting</span>
          </a>
        </div>
        <a href="/Alerting/Rules/#rules">Rules</a><br />
        <a href="/Alerting/Templates/">Templates</a><br />
        <a href="/Alerting/Transports/">Transports</a><br />
        <a href="/Alerting/"><strong>More...</strong></a>
    </div>
    <div class="home-box">
        <div class="home-header">
          <a href="/API/">
            <i class="fab fa-connectdevelop"></i>
            <span>API</span>
          </a>
        </div>
        <a href="/API/">Using the API</a><br />
        <a href="/API/#endpoint-categories">API Endpoints</a><br />
        <br />
        <br />
    </div>
    <div class="home-box">
        <div class="home-header">
          <a href="/Support/">
            <i class="fas fa-ambulance"></i>
            <span>Support</span>
          </a>
        </div>
        <a href="/Support/FAQ/">FAQ</a><br />
        <a href="/Support/Install%20Validation/">Install validation</a><br />
        <a href="/Support/Performance/">Performance tweaks</a><br />
        <a href="/Support/"><strong>More...</strong></a>
    </div>
    <div class="home-box">
        <div class="home-header">
          <a href="/Developing/">
            <i class="fas fa-code-branch"></i>
            <span>Developing</span>
          </a>
        </div>
        <a href="/Developing/Getting-Started/">Getting Started</a><br />
        <a href="/Developing/Support-New-OS/">Support for a new OS</a><br />
    </div>
</div>
